// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {


  /// @brief e+e- > KS0 KL0
  class SND_2024_I2809918 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(SND_2024_I2809918);

    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      declare(FinalState(), "FS");
      book(_nK0K0, 1, 1, 1);
      for (const string& en : _nK0K0.binning().edges<0>()) {
        const double eval = stod(en)*MeV;
        if (isCompatibleWithSqrtS(eval)) {
          _sqs = en; break;
        }
      }
      raiseBeamErrorIf(_sqs.empty());
    }


    /// Perform the per-event analysis
    void analyze(const Event& event) {

      const FinalState& fs = apply<FinalState>(event, "FS");

      map<long,int> nCount;
      int ntotal(0);
      for (const Particle& p : fs.particles()) {
        nCount[p.pid()] += 1;
        ++ntotal;
      }
      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) {
        _nK0K0->fill(_sqs);
      }

    }


    /// Normalise histograms etc., after the run
    void finalize() {
      scale(_nK0K0, crossSection()/sumOfWeights()/nanobarn);
    }

    /// @}

    /// @name Histograms
    /// @{
    BinnedHistoPtr<string> _nK0K0;
    string _sqs = "";
    /// @}

  };


  RIVET_DECLARE_PLUGIN(SND_2024_I2809918);
}
